#! /usr/bin/env bash

PICARD='Tools/picard-tools-2.5.0/picard.jar'
GATK='Tools/GenomeAnalysisTK.jar -drf DuplicateRead'
infolder=BAM
outfolder=gatk_variants
errfolder=logs
gvcffolder=gvcf
vcffolder=vcf

# define local variable
bundle=Reference
reference=${bundle}/ucsc.hg19.fasta 

# INDEL gold standards
mills=${bundle}/Mills_and_1000G_gold_standard.indels.hg19.sites.vcf.gz
phase1indel=${bundle}/1000G_phase1.indels.hg19.sites.vcf.gz
 
# pick one of the former two as gold_indels set
gold_indels=${mills}
 
# SNP gold standards
dbsnp=${bundle}/dbsnp_138.hg19.vcf.gz
hapmap=${bundle}/hapmap_3.3.hg19.sites.vcf.gz
phase1snp=${bundle}/1000G_phase1.snps.high_confidence.hg19.sites.vcf.gz
omni=${bundle}/1000G_omni2.5.hg19.sites.vcf.gz

mkdir -p ${outfolder}
mkdir -p ${errfolder}
mkdir -p ${gvcffolder}
mkdir -p ${vcffolder}


LIST=$(cat LIST.TXT)
for file in ${LIST}; do
	infile=${file}
	outfile=$"nmsrt_$file"
	echo $outfile

#sort mappings by name to keep paired reads together
	echo sort mappings
	
	java -Xmx6g -jar $PICARD SortSam \
		I=${infolder}/${infile} \
		O=${outfolder}/${outfile} \
		SO=coordinate \
		VALIDATION_STRINGENCY=LENIENT \
		2>${errfolder}/${file}_SortSam_queryname.err

#apply Picard FixMateInformation.jar 
	echo fixing mates
	
	infile=${outfile}	
	outfile=$"fxmt_$infile"

	java -Xmx6g -jar $PICARD FixMateInformation \
		I=${outfolder}/${infile} \
		O=${outfolder}/${outfile} \
		SO=coordinate \
		VALIDATION_STRINGENCY=LENIENT \
		2>${errfolder}/${file}_FixMateInformation.err

# apply Picard MarkDuplicates.jar
#	echo duplicate mark
#	
#	infile=${outfile}	
#	outfile=$"mdup_$infile"
#	java -Xmx6g -jar $PICARD MarkDuplicatesWithMateCigar \
#		I=${outfolder}/${infile} \
#		O=${outfolder}/${outfile} \
#		REMOVE_DUPLICATES=true \
#		M=${outfolder}/${file}_duplicate_metrics.txt \
#		VALIDATION_STRINGENCY=LENIENT \
#		2>${errfolder}/${file}_MarkDuplicates.err

# apply build index with picard
	echo build index with picard
	
	infile=${outfile}	
	java -Xmx6g -jar $PICARD BuildBamIndex \
		I=${outfolder}/${infile}
		2>${errfolder}/${file}_BuildBamIndex.err
		
#identify regions for indel local realignment of the selected chromosome with gatk RealignerTargetCreator
	echo identify regions 4 realignment
			 
	java -Xmx6g -jar $GATK \
		-T RealignerTargetCreator \
		-R ${reference} \
		-I ${outfolder}/${infile} \
		-L chr13 \
		-L chr17 \
		-known ${gold_indels} \
		-o ${outfolder}/${file}_target_intervals.list \
		2>${errfolder}/${file}_RealignerTargetCreator.err

# perform indel local realignment of the selected chromosome with gatk IndelRealigner
	echo perform indel  realignment
	
	infile=${outfile}
	outfile=$"ralgn_reads_$infile"
	 
	java -Xmx6g -jar $GATK \
		-T IndelRealigner \
		-R ${reference} \
		-I ${outfolder}/${infile} \
		-L chr13 \
		-L chr17 \
		-targetIntervals ${outfolder}/${file}_target_intervals.list \
		-known ${gold_indels} \
		-o ${outfolder}/${outfile} \
		2>${errfolder}/${file}_IndelRealigner.err
		
# Analyze patterns of covariation in the sequence dataset with gatk BaseRecalibrator
	echo BaseRecalibrator run 1
	
	infile=${outfile}
	 
	java -Xmx6g -jar $GATK \
		-T BaseRecalibrator \
		-R ${reference} \
		-I ${outfolder}/${infile} \
		-L chr13 \
		-L chr17 \
		-knownSites ${dbsnp} \
		-knownSites ${gold_indels} \
		-o ${outfolder}/${file}_recal_data.table \
		2>${errfolder}/${file}_BaseRecalibrator.err

# do a second pass to analyze covariation remaining after recalibration with gatk BaseRecalibrator Use the same BAM data as in the first iteration
	echo BaseRecalibrator run 2
	
	java -Xmx6g -jar $GATK \
		-T BaseRecalibrator \
		-R ${reference} \
		-I ${outfolder}/${infile} \
		-L chr13 \
		-L chr17 \
		-knownSites ${dbsnp} \
		-knownSites ${gold_indels} \
		-BQSR ${outfolder}/${file}_recal_data.table \
		-o ${outfolder}/${file}_post_recal_data.table \
		2>${errfolder}/${file}_BaseRecalibrator_2.err
		
#generate before/after plots with gatk AnalyzeCovariates
	echo generate before_after plots

	java -Xmx6g -jar $GATK \
		-T AnalyzeCovariates \
		-R ${reference} \
		-L chr13 \
		-L chr17 \
		-before ${outfolder}/${file}_recal_data.table \
		-after ${outfolder}/${file}_post_recal_data.table \
		-plots ${outfolder}/${file}_recalibration_plots.pdf \
		2>${errfolder}/${file}_AnalyzeCovariates.err
		
#apply the recalibration to the sequence data with gatk PrintReads
	echo apply the recalibration
	
	infile=${outfile}
	java -Xmx6g -jar $GATK \
		-T PrintReads \
		-R ${reference} \
		-L chr13 \
		-L chr17 \
		-I ${outfolder}/${infile} \
		-BQSR ${outfolder}/${file}_recal_data.table \
		-o ${outfolder}/${file}_recal_reads.bam \
		2>${errfolder}/${file}_PrintReads.err

# Call raw SNP and Indel variants with gatk HaplotypeCaller
	echo Call raw SNP and Indel variants gVCF 
	
	infile=${outfile}
	java -Xmx6g -jar $GATK \
		-T HaplotypeCaller \
		-R ${reference} \
		-I ${outfolder}/${infile} \
		-L chr13 \
		-L chr17 \
		--dbsnp ${dbsnp}\
		--genotyping_mode DISCOVERY \
		--emitRefConfidence GVCF \
		-stand_emit_conf 10 \
		-stand_call_conf 30 \
		-o ${gvcffolder}/${file}raw_variants.g.vcf \
		-A AlleleBalance \
		-A BaseCounts \
		-A StrandOddsRatio \
		-A StrandBiasBySample \
		-A FisherStrand \
		2>${errfolder}/${file}HaplotypeCallerGVCF.err
		
# Call raw SNP and Indel variants with gatk HaplotypeCaller
	echo Annotate Variants
	
	infile=${file}raw_variants.g.vcf
	java -Xmx6g -jar $GATK \
			-T VariantAnnotator \
			-R ${reference} \
			-V gvcf/${infile} \
			-all \
			--dbsnp ${dbsnp} \
			-L chr13 \
			-L chr17 \
			-o gvcf/${file}raw_variants.annot.g.vcf \
			2>${errfolder}/${file}VariantAnnotator.err
			
	
#Call raw SNP and Indel variants with gatk HaplotypeCaller
#	echo Call raw SNP and Indel variants VCF 
	
#	infile=${outfile}
#	java -Xmx6g -jar $GATK \
#		-T HaplotypeCaller \
#		-R ${reference} \
#		-I ${outfolder}/${infile} \
#		-L chr13 \
#		-L chr17 \
#		--dbsnp ${dbsnp}\
#		--genotyping_mode DISCOVERY \
#		-stand_emit_conf 10 \
#		-stand_call_conf 30 \
#		-o ${vcffolder}/${file}raw_variants.vcf \
#		2>${errfolder}/${file}HaplotypeCallerVCF.err


	
done